% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-aic-exponential.R
\name{util_exponential_aic}
\alias{util_exponential_aic}
\title{Calculate Akaike Information Criterion (AIC) for Exponential Distribution}
\usage{
util_exponential_aic(.x)
}
\arguments{
\item{.x}{A numeric vector containing the data to be fitted to an exponential distribution.}
}
\value{
The AIC value calculated based on the fitted exponential distribution to the provided data.
}
\description{
This function estimates the rate parameter of an exponential distribution from the provided data using maximum likelihood estimation,
and then calculates the AIC value based on the fitted distribution.
}
\details{
This function calculates the Akaike Information Criterion (AIC) for an exponential distribution fitted to the provided data.

This function fits an exponential distribution to the provided data using maximum likelihood estimation. It estimates the rate parameter
of the exponential distribution using maximum likelihood estimation. Then, it calculates the AIC value based on the fitted distribution.

Initial parameter estimates: The function uses the reciprocal of the mean of the data as the initial estimate for the rate parameter.

Optimization method: The function uses the optim function for optimization. You might explore different optimization methods within
optim for potentially better performance.

Goodness-of-fit: While AIC is a useful metric for model comparison, it's recommended to also assess the goodness-of-fit of the chosen
model using visualization and other statistical tests.
}
\examples{
# Example 1: Calculate AIC for a sample dataset
set.seed(123)
x <- rexp(30)
util_exponential_aic(x)

}
\seealso{
Other Utility: 
\code{\link{check_duplicate_rows}()},
\code{\link{convert_to_ts}()},
\code{\link{quantile_normalize}()},
\code{\link{tidy_mcmc_sampling}()},
\code{\link{util_beta_aic}()},
\code{\link{util_binomial_aic}()},
\code{\link{util_cauchy_aic}()},
\code{\link{util_chisq_aic}()},
\code{\link{util_gamma_aic}()},
\code{\link{util_geometric_aic}()},
\code{\link{util_hypergeometric_aic}()},
\code{\link{util_logistic_aic}()},
\code{\link{util_lognormal_aic}()},
\code{\link{util_normal_aic}()},
\code{\link{util_pareto_aic}()},
\code{\link{util_poisson_aic}()},
\code{\link{util_uniform_aic}()},
\code{\link{util_weibull_aic}()}
}
\author{
Steven P. Sanderson II, MPH
}
\concept{Utility}
